%% $Id: aerocoeffs.m,v 1.1 2007-02-11 22:44:25 anders Exp $
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Virtual wind tunnel experiment with LZ-129 Hindenburg model.
%%
%%    Copyright (C) 2007  Anders Gidenstam  (anders(at)gidenstam.org)
%%
%%    This program is free software; you can redistribute it and/or modify
%%    it under the terms of the GNU General Public License as published by
%%    the Free Software Foundation; either version 2 of the License, or
%%    (at your option) any later version.
%%
%%    This program is distributed in the hope that it will be useful,
%%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%%    GNU General Public License for more details.
%%
%%    You should have received a copy of the GNU General Public License
%%    along with this program; if not, write to the Free Software
%%    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

load -force "solidforce.dat";

%% Simulation scaling

%% Reference length
L = 100; % meter
%% Reference speed
U = 20; % meter/sec

%% Freestream velocity
u = 1;
%% Air density
rho = 1;
%% Freestream dynamic preassure
q_inf = rho * u^2 / 2;

%% Volume
vol = 1982.2 / L^3;

figure;
t=solidforce(:,1);
F=solidforce(:,2:4);
plot(t(10:length(t)), F(10:length(t),:));
title('Forces');

figure;
M=solidforce(:,8:10);
plot(t,M);
title('Moments');

x_force = mean(F(floor(2*length(t)/3):length(t),1));
y_force = mean(F(floor(2*length(t)/3):length(t),2));
z_force = mean(F(floor(2*length(t)/3):length(t),3));

x_moment = mean(M(floor(2*length(t)/3):length(t),1));
y_moment = mean(M(floor(2*length(t)/3):length(t),2));
z_moment = mean(M(floor(2*length(t)/3):length(t),3));

%% Calculate aerodynamic parameters

%% Drag
%%   CD = D / (q_inf * (vol)^(2/3))
D = x_force;
CD = D / (q_inf * vol^(2/3))

%% Lift
%%   CL = L / (q * (vol)^(2/3))
L = z_force;
CL = L / (q_inf * vol^(2/3))

%% Side (NOTE: I am not certain about the sign)
%%   CY = Y / (q * (vol)^(2/3))
Y = y_force;
CY = Y / (q_inf * vol^(2/3))

%% Pitch moment
%%   Cmp = Mp / (q * vol)
Mp = y_moment;
Cmp = Mp / (q_inf * vol)

%% Yaw moment
%%   Cmy = My / (q * vol)
My = z_moment;
Cmy = My / (q_inf * vol)

%% Roll moment
%%   Cmr = Mr / (q * vol)
Mr = x_moment;
Cmr = Mr / (q_inf * vol)
